.. _api:

API
===

.. automodule:: pymapd
   :members: connect, Connection, Cursor


Exceptions
----------

.. automodule:: pymapd
   :members: Error, InterfaceError, DatabaseError, OperationalError, IntegrityError, InternalError, ProgrammingError, NotSupportedError
